@@ -1,14 +1,10 @@
-__version__ = '1.7.1'
+__version__ = '3.0.2'
 
 import logging
 
-logging.basicConfig()
+#logging.basicConfig()
 logger = logging.getLogger(__name__)
 
-from . import syntax
-
-contract_expression = syntax.contract_expression
-
 from .interface import (Contract, ContractNotRespected,
                         CannotDecorateClassmethods,
                         ContractSyntaxError, ContractException)
@@ -23,7 +19,6 @@ from .main import (check, fail, check_multiple, contract_decorator,
 def contract(*args, **kwargs):
     return contract_decorator(*args, **kwargs)
 
-
 contract.__doc__ = contract_decorator.__doc__
 
 from .main import new_contract as new_contract_main
@@ -41,15 +36,11 @@ from .enabling import disable_all, enable_all, all_disabled
 from .interface import describe_value, describe_type, describe_value_multiline
 from .utils import *
 
-# For backwards compatibility
-# contracts = contract
-
-# After everything is loaded, load aliases
-from .library import miscellaneous_aliases
-
-from .metaclass import ContractsMeta
+from .metaclass import ContractsMeta, with_metaclass
 
 ContractsMeta.__module__ = 'contracts'
 
 # And after everything else is loaded, load the  utils
 from .useful_contracts import *
+# After everything is loaded, load aliases
+# from .library import miscellaneous_aliases  # @UnusedImport
